@@ -210,37 +210,46 @@ def _join_path(base_path: str, context: str) -> str:
     ).replace("\\", "/")
 
 
-def set_context(context: str, mode: str = "both", overwrite: bool = False):
-    global MODE, MODE_TOKEN, CONTEXT_READ_TOKEN, CONTEXT_WRITE_TOKEN
-    MODE = mode
-    _validate_mode_nesting(CONTEXT_MODE.get(), mode)
-    MODE_TOKEN = CONTEXT_MODE.set(mode)
+def set_context(
+    context: str,
+    mode: str = "both",
+    overwrite: bool = False,
+    relative: bool = True,
+):
+    if mode == "both":
+        if relative:
+            assert CONTEXT_WRITE.get() == CONTEXT_READ.get()
+            context = _join_path(CONTEXT_WRITE.get(), context)
+            CONTEXT_WRITE.set(context)
+            CONTEXT_READ.set(context)
+        else:
+            CONTEXT_WRITE.set(context)
+            CONTEXT_READ.set(context)
+    elif mode == "write":
+        if relative:
+            context = _join_path(CONTEXT_WRITE.get(), context)
+            CONTEXT_WRITE.set(context)
+        else:
+            CONTEXT_WRITE.set(context)
+    elif mode == "read":
+        if relative:
+            context = _join_path(CONTEXT_READ.get(), context)
+            CONTEXT_READ.set(context)
+        else:
+            CONTEXT_READ.set(context)
 
-    if overwrite and context in unify.get_contexts():
+    context_exists_remote = context in unify.get_contexts()
+    if overwrite and context_exists_remote:
         if mode == "read":
             raise Exception(f"Cannot overwrite logs in read mode.")
         unify.delete_context(context)
-    if context not in unify.get_contexts():
+    if not context_exists_remote:
         unify.create_context(context)
 
-    if mode in ("both", "write"):
-        CONTEXT_WRITE_TOKEN = CONTEXT_WRITE.set(
-            _join_path(CONTEXT_WRITE.get(), context),
-        )
-    if mode in ("both", "read"):
-        CONTEXT_READ_TOKEN = CONTEXT_READ.set(
-            _join_path(CONTEXT_READ.get(), context),
-        )
-
 
 def unset_context():
-    global MODE, MODE_TOKEN, CONTEXT_READ_TOKEN, CONTEXT_WRITE_TOKEN
-    if MODE in ("both", "write"):
-        CONTEXT_WRITE.reset(CONTEXT_WRITE_TOKEN)
-    if MODE in ("both", "read"):
-        CONTEXT_READ.reset(CONTEXT_READ_TOKEN)
-
-    CONTEXT_MODE.reset(MODE_TOKEN)
+    CONTEXT_WRITE.set("")
+    CONTEXT_READ.set("")
 
 
 def get_active_context():
@@ -265,16 +274,23 @@ class Context:
         _validate_mode_nesting(CONTEXT_MODE.get(), self._mode)
         self._mode_token = CONTEXT_MODE.set(self._mode)
 
-        if self._mode in ("both", "write"):
-            self._context_write_token = CONTEXT_WRITE.set(
-                _join_path(CONTEXT_WRITE.get(), self._context),
-            )
-        if self._mode in ("both", "read"):
-            self._context_read_token = CONTEXT_READ.set(
-                _join_path(CONTEXT_READ.get(), self._context),
-            )
+        if self._mode == "both":
+            assert CONTEXT_WRITE.get() == CONTEXT_READ.get()
+            self._context = _join_path(CONTEXT_WRITE.get(), self._context)
+            self._context_write_token = CONTEXT_WRITE.set(self._context)
+            self._context_read_token = CONTEXT_READ.set(self._context)
+        elif self._mode == "write":
+            self._context = _join_path(CONTEXT_WRITE.get(), self._context)
+            self._context_write_token = CONTEXT_WRITE.set(self._context)
+        elif self._mode == "read":
+            self._context = _join_path(CONTEXT_READ.get(), self._context)
+            self._context_read_token = CONTEXT_READ.set(self._context)
 
-        if self._overwrite and self._context in unify.get_contexts():
+        context_exists_remote = self._context in unify.get_contexts()
+
+        if not context_exists_remote:
+            unify.create_context(self._context, is_versioned=self._is_versioned)
+        elif self._overwrite and context_exists_remote:
             if self._mode == "read":
                 raise Exception(f"Cannot overwrite logs in read mode.")
 
@@ -282,9 +298,13 @@ class Context:
             unify.create_context(self._context, is_versioned=self._is_versioned)
 
     def __exit__(self, *args, **kwargs):
-        if self._mode in ("both", "write"):
+        if self._mode == "both":
+            assert CONTEXT_WRITE.get() == CONTEXT_READ.get()
             CONTEXT_WRITE.reset(self._context_write_token)
-        if self._mode in ("both", "read"):
+            CONTEXT_READ.reset(self._context_read_token)
+        elif self._mode == "write":
+            CONTEXT_WRITE.reset(self._context_write_token)
+        elif self._mode == "read":
             CONTEXT_READ.reset(self._context_read_token)
 
         CONTEXT_MODE.reset(self._mode_token)
