@@ -51,9 +51,11 @@ class _Client(ABC):
         stream_options: Optional[ChatCompletionStreamOptionsParam],
         temperature: Optional[float],
         top_p: Optional[float],
+        service_tier: Optional[str],
         tools: Optional[Iterable[ChatCompletionToolParam]],
         tool_choice: Optional[ChatCompletionToolChoiceOptionParam],
         parallel_tool_calls: Optional[bool],
+        reasoning_effort: Optional[str],
         # platform arguments
         use_custom_keys: bool,
         tags: Optional[List[str]],
@@ -92,9 +94,11 @@ class _Client(ABC):
         self._stream_options = None
         self._temperature = None
         self._top_p = None
+        self._service_tier = None
         self._tools = None
         self._tool_choice = None
         self._parallel_tool_calls = None
+        self._reasoning_effort = None
         self._use_custom_keys = None
         self._tags = None
         self._drop_params = None
@@ -127,9 +131,11 @@ class _Client(ABC):
         self.set_stream_options(stream_options)
         self.set_temperature(temperature)
         self.set_top_p(top_p)
+        self.set_service_tier(service_tier)
         self.set_tools(tools)
         self.set_tool_choice(tool_choice)
         self.set_parallel_tool_calls(parallel_tool_calls)
+        self.set_reasoning_effort(reasoning_effort)
         # platform arguments
         self.set_use_custom_keys(use_custom_keys)
         self.set_tags(tags)
@@ -166,9 +172,11 @@ class _Client(ABC):
             "stream_options": stream_options,
             "temperature": temperature,
             "top_p": top_p,
+            "service_tier": service_tier,
             "tools": tools,
             "tool_choice": tool_choice,
             "parallel_tool_calls": parallel_tool_calls,
+            "reasoning_effort": reasoning_effort,
         }
 
     # Properties #
@@ -341,6 +349,16 @@ class _Client(ABC):
         """
         return self._top_p
 
+    @property
+    def service_tier(self) -> Optional[str]:
+        """
+        Get the default service tier, if set.
+
+        Returns:
+            The default service tier.
+        """
+        return self._service_tier
+
     @property
     def tools(self) -> Optional[Iterable[ChatCompletionToolParam]]:
         """
@@ -371,6 +389,16 @@ class _Client(ABC):
         """
         return self._parallel_tool_calls
 
+    @property
+    def reasoning_effort(self) -> Optional[str]:
+        """
+        Get the default reasoning, if set.
+
+        Returns:
+            The default reasoning.
+        """
+        return self._reasoning_effort
+
     @property
     def use_custom_keys(self) -> bool:
         """
@@ -763,6 +791,19 @@ class _Client(ABC):
         self._top_p = value
         return self
 
+    def set_service_tier(self, value: Optional[str]) -> Self:
+        """
+        Set the default service tier.  # noqa: DAR101.
+
+        Args:
+            value: The default service tier.
+
+        Returns:
+            This client, useful for chaining inplace calls.
+        """
+        self._service_tier = value
+        return self
+
     def set_tools(self, value: Iterable[ChatCompletionToolParam]) -> Self:
         """
         Set the default tools.  # noqa: DAR101.
@@ -802,6 +843,19 @@ class _Client(ABC):
         self._parallel_tool_calls = value
         return self
 
+    def set_reasoning_effort(self, value: str) -> Self:
+        """
+        Set the default reasoning effort.  # noqa: DAR101.
+
+        Args:
+            value: The default reasoning effort.
+
+        Returns:
+            This client, useful for chaining inplace calls.
+        """
+        self._reasoning_effort = value
+        return self
+
     def set_use_custom_keys(self, value: bool) -> Self:
         """
         Set the default use custom keys bool.  # noqa: DAR101.
@@ -1132,6 +1186,15 @@ class _Client(ABC):
         """
         return self.set_top_p(self._defaults["top_p"])
 
+    def reset_service_tier(self) -> Self:
+        """
+        Reset the service tier to its default value.
+
+        Returns:
+            This client, useful for chaining inplace calls.
+        """
+        return self.set_service_tier(self._defaults["service_tier"])
+
     def reset_tools(self) -> Self:
         """
         Reset the tools to their default value.
@@ -1159,6 +1222,15 @@ class _Client(ABC):
         """
         return self.set_parallel_tool_calls(self._defaults["parallel_tool_calls"])
 
+    def reset_reasoning_effort(self) -> Self:
+        """
+        Reset the reasoning effort to its default value.
+
+        Returns:
+            This client, useful for chaining inplace calls.
+        """
+        return self.set_reasoning_effort(self._defaults["reasoning_effort"])
+
     def reset_all(self) -> Self:
         """
         Reset base client properties to their default values.
@@ -1182,9 +1254,11 @@ class _Client(ABC):
         self.reset_stream_options()
         self.reset_temperature()
         self.reset_top_p()
+        self.reset_service_tier()
         self.reset_tools()
         self.reset_tool_choice()
         self.reset_parallel_tool_calls()
+        self.reset_reasoning_effort()
         return self
 
     # Credits #
@@ -1244,6 +1318,7 @@ class _Client(ABC):
                         stream_options=self._stream_options,
                         temperature=self._temperature,
                         top_p=self._top_p,
+                        service_tier=self._service_tier,
                         tools=self._tools,
                         tool_choice=self._tool_choice,
                         parallel_tool_calls=self._parallel_tool_calls,
@@ -1292,6 +1367,7 @@ class _Client(ABC):
                     stream_options=self._stream_options,
                     temperature=self._temperature,
                     top_p=self._top_p,
+                    service_tier=self._service_tier,
                     tools=self._tools,
                     tool_choice=self._tool_choice,
                     parallel_tool_calls=self._parallel_tool_calls,
@@ -1344,9 +1420,11 @@ class _Client(ABC):
         stream_options: Optional[ChatCompletionStreamOptionsParam],
         temperature: Optional[float],
         top_p: Optional[float],
+        service_tier: Optional[str],
         tools: Optional[Iterable[ChatCompletionToolParam]],
         tool_choice: Optional[ChatCompletionToolChoiceOptionParam],
         parallel_tool_calls: Optional[bool],
+        reasoning_effort: Optional[str],
         # platform arguments
         use_custom_keys: bool,
         tags: Optional[List[str]],
