@@ -52,9 +52,11 @@ class _MultiClient(_Client, abc.ABC):
         stop: Union[Optional[str], List[str]] = None,
         temperature: Optional[float] = 1.0,
         top_p: Optional[float] = None,
+        service_tier: Optional[str] = None,
         tools: Optional[Iterable[ChatCompletionToolParam]] = None,
         tool_choice: Optional[ChatCompletionToolChoiceOptionParam] = None,
         parallel_tool_calls: Optional[bool] = None,
+        reasoning_effort: Optional[str] = None,
         # platform arguments
         use_custom_keys: bool = False,
         tags: Optional[List[str]] = None,
@@ -235,9 +237,11 @@ class _MultiClient(_Client, abc.ABC):
             stream_options=None,
             temperature=temperature,
             top_p=top_p,
+            service_tier=service_tier,
             tools=tools,
             tool_choice=tool_choice,
             parallel_tool_calls=parallel_tool_calls,
+            reasoning_effort=reasoning_effort,
             # platform arguments
             use_custom_keys=use_custom_keys,
             tags=tags,
@@ -289,9 +293,11 @@ class _MultiClient(_Client, abc.ABC):
                 stop=self.stop,
                 temperature=self.temperature,
                 top_p=self.top_p,
+                service_tier=self.service_tier,
                 tools=self.tools,
                 tool_choice=self.tool_choice,
                 parallel_tool_calls=self.parallel_tool_calls,
+                reasoning_effort=self.reasoning_effort,
                 # platform arguments
                 use_custom_keys=self.use_custom_keys,
                 tags=self.tags,
@@ -480,6 +486,7 @@ class _MultiClient(_Client, abc.ABC):
         tools: Optional[Iterable[ChatCompletionToolParam]] = None,
         tool_choice: Optional[ChatCompletionToolChoiceOptionParam] = None,
         parallel_tool_calls: Optional[bool] = None,
+        reasoning_effort: Optional[str] = None,
         # platform arguments
         use_custom_keys: Optional[bool] = None,
         tags: Optional[List[str]] = None,
@@ -705,6 +712,7 @@ class _MultiClient(_Client, abc.ABC):
                 parallel_tool_calls,
                 self._parallel_tool_calls,
             ),
+            reasoning_effort=_default(reasoning_effort, self._reasoning_effort),
             # platform arguments
             use_custom_keys=_default(use_custom_keys, self._use_custom_keys),
             tags=_default(tags, self._tags),
@@ -756,6 +764,7 @@ class MultiUnify(_MultiClient):
         tools: Optional[Iterable[ChatCompletionToolParam]] = None,
         tool_choice: Optional[ChatCompletionToolChoiceOptionParam] = None,
         parallel_tool_calls: Optional[bool] = None,
+        reasoning_effort: Optional[str] = None,
         # platform arguments
         use_custom_keys: bool = False,
         tags: Optional[List[str]] = None,
@@ -769,6 +778,7 @@ class MultiUnify(_MultiClient):
         # passthrough arguments
         extra_headers: Optional[Headers] = None,
         extra_query: Optional[Query] = None,
+        service_tier: Optional[str] = None,
         **kwargs,
     ) -> Union[Union[str, ChatCompletion], Dict[str, Union[str, ChatCompletion]]]:
         kw = dict(
@@ -788,6 +798,7 @@ class MultiUnify(_MultiClient):
             tools=tools,
             tool_choice=tool_choice,
             parallel_tool_calls=parallel_tool_calls,
+            reasoning_effort=reasoning_effort,
             use_custom_keys=use_custom_keys,
             tags=tags,
             drop_params=drop_params,
@@ -797,6 +808,7 @@ class MultiUnify(_MultiClient):
             return_full_completion=return_full_completion,
             extra_headers=extra_headers,
             extra_query=extra_query,
+            service_tier=service_tier,
             **kwargs,
         )
         multi_message = isinstance(kw["messages"], dict)
@@ -912,6 +924,7 @@ class AsyncMultiUnify(_MultiClient):
         tools: Optional[Iterable[ChatCompletionToolParam]] = None,
         tool_choice: Optional[ChatCompletionToolChoiceOptionParam] = None,
         parallel_tool_calls: Optional[bool] = None,
+        reasoning_effort: Optional[str] = None,
         # platform arguments
         use_custom_keys: bool = False,
         tags: Optional[List[str]] = None,
@@ -925,6 +938,7 @@ class AsyncMultiUnify(_MultiClient):
         # passthrough arguments
         extra_headers: Optional[Headers] = None,
         extra_query: Optional[Query] = None,
+        service_tier: Optional[str] = None,
         **kwargs,
     ) -> Dict[str, str]:
         kw = dict(
@@ -944,6 +958,7 @@ class AsyncMultiUnify(_MultiClient):
             tools=tools,
             tool_choice=tool_choice,
             parallel_tool_calls=parallel_tool_calls,
+            reasoning_effort=reasoning_effort,
             use_custom_keys=use_custom_keys,
             tags=tags,
             drop_params=drop_params,
@@ -954,6 +969,7 @@ class AsyncMultiUnify(_MultiClient):
             local_cache=local_cache,
             extra_headers=extra_headers,
             extra_query=extra_query,
+            service_tier=service_tier,
             **kwargs,
         )
         multi_message = isinstance(messages, dict)
