@@ -72,9 +72,11 @@ class _UniClient(_Client, abc.ABC):
         stream_options: Optional[ChatCompletionStreamOptionsParam] = None,
         temperature: Optional[float] = 1.0,
         top_p: Optional[float] = None,
+        service_tier: Optional[str] = None,
         tools: Optional[Iterable[ChatCompletionToolParam]] = None,
         tool_choice: Optional[ChatCompletionToolChoiceOptionParam] = None,
         parallel_tool_calls: Optional[bool] = None,
+        reasoning_effort: Optional[str] = None,
         # platform arguments
         use_custom_keys: bool = False,
         tags: Optional[List[str]] = None,
@@ -266,9 +268,11 @@ class _UniClient(_Client, abc.ABC):
             stream_options=stream_options,
             temperature=temperature,
             top_p=top_p,
+            service_tier=service_tier,
             tools=tools,
             tool_choice=tool_choice,
             parallel_tool_calls=parallel_tool_calls,
+            reasoning_effort=reasoning_effort,
             # platform arguments
             use_custom_keys=use_custom_keys,
             tags=tags,
@@ -688,6 +692,7 @@ class _UniClient(_Client, abc.ABC):
         tools: Optional[Iterable[ChatCompletionToolParam]] = None,
         tool_choice: Optional[ChatCompletionToolChoiceOptionParam] = None,
         parallel_tool_calls: Optional[bool] = None,
+        reasoning_effort: Optional[str] = None,
         # platform arguments
         use_custom_keys: Optional[bool] = None,
         tags: Optional[List[str]] = None,
@@ -703,6 +708,7 @@ class _UniClient(_Client, abc.ABC):
         # passthrough arguments
         extra_headers: Optional[Headers] = None,
         extra_query: Optional[Query] = None,
+        service_tier: Optional[str] = None,
         **kwargs,
     ):
         """Generate a ChatCompletion response for the specified endpoint,
@@ -908,12 +914,14 @@ class _UniClient(_Client, abc.ABC):
             stream_options=_default(stream_options, self._stream_options),
             temperature=_default(temperature, self._temperature),
             top_p=_default(top_p, self._top_p),
+            service_tier=_default(service_tier, self._service_tier),
             tools=_default(tools, self._tools),
             tool_choice=_default(tool_choice, self._tool_choice),
             parallel_tool_calls=_default(
                 parallel_tool_calls,
                 self._parallel_tool_calls,
             ),
+            reasoning_effort=_default(reasoning_effort, self._reasoning_effort),
             # platform arguments
             use_custom_keys=_default(use_custom_keys, self._use_custom_keys),
             tags=_default(tags, self._tags),
@@ -1181,9 +1189,11 @@ class Unify(_UniClient):
         stream_options: Optional[ChatCompletionStreamOptionsParam],
         temperature: Optional[float],
         top_p: Optional[float],
+        service_tier: Optional[str],
         tools: Optional[Iterable[ChatCompletionToolParam]],
         tool_choice: Optional[ChatCompletionToolChoiceOptionParam],
         parallel_tool_calls: Optional[bool],
+        reasoning_effort: Optional[str],
         # platform arguments
         use_custom_keys: bool,
         tags: Optional[List[str]],
@@ -1214,9 +1224,11 @@ class Unify(_UniClient):
             stop=stop,
             temperature=temperature,
             top_p=top_p,
+            service_tier=service_tier,
             tools=tools,
             tool_choice=tool_choice,
             parallel_tool_calls=parallel_tool_calls,
+            reasoning_effort=reasoning_effort,
             extra_headers=extra_headers,
             extra_query=extra_query,
             extra_body=kwargs,
@@ -1375,7 +1387,7 @@ class AsyncUnify(_UniClient):
         if "response_format" in kw and kw["response_format"]:
             chat_method = self._client.beta.chat.completions.parse
             if "stream" in kw:
-                del kw["stream"] # .parse() does not accept the stream argument
+                del kw["stream"]  # .parse() does not accept the stream argument
         else:
             chat_method = self._client.chat.completions.create
         chat_completion = None
@@ -1488,6 +1500,7 @@ class AsyncUnify(_UniClient):
         tools: Optional[Iterable[ChatCompletionToolParam]],
         tool_choice: Optional[ChatCompletionToolChoiceOptionParam],
         parallel_tool_calls: Optional[bool],
+        reasoning_effort: Optional[str],
         # platform arguments
         use_custom_keys: bool,
         tags: Optional[List[str]],
@@ -1502,6 +1515,7 @@ class AsyncUnify(_UniClient):
         # passthrough arguments
         extra_headers: Optional[Headers],
         extra_query: Optional[Query],
+        service_tier: Optional[str] = None,
         **kwargs,
     ) -> Union[AsyncGenerator[str, None], str]:  # noqa: DAR101, DAR201, DAR401
         prompt = Prompt(
@@ -1524,6 +1538,8 @@ class AsyncUnify(_UniClient):
             extra_headers=extra_headers,
             extra_query=extra_query,
             extra_body=kwargs,
+            reasoning_effort=reasoning_effort,
+            service_tier=service_tier,
         )
         if stream:
             return self._generate_stream(
